@@ -1526,8 +1526,11 @@ msole_metadata_write_section (WritePropState *state, gboolean user)
 	} else
 		i = 1;
 
+	offsets[i].offset = gsf_output_tell (state->out);
+
 	/* 2) props */
 	for (; ptr != NULL && i < count ; ptr = ptr->next, i++) {
+		offsets[i].offset = gsf_output_tell (state->out);
 		prop = ptr->data;
 		name = gsf_doc_prop_get_name (prop);
 		if (user) {
@@ -1540,13 +1543,12 @@ msole_metadata_write_section (WritePropState *state, gboolean user)
 		} else {
 			map = msole_gsf_name_to_prop (name);
 			if (map == NULL) {
-				g_warning ("Missing map for builting property '%s'", name);
+				g_warning ("Missing map for built-in property '%s'", name);
 				continue;
 			}
 			offsets[i].id = map->id;
 		}
 
-		offsets[i].offset = gsf_output_tell (state->out);
 		msole_metadata_write_prop (state, name,
 			gsf_doc_prop_get_val  (prop), FALSE);
 		if (gsf_doc_prop_get_link (prop)) {
